==> rodent-4.8.0.tar.gz: rodent-4.8.0/files.h <==
/* files */
#define CONFIG_BUILD "5858"
#ifndef CONFIG_BUILD
# define CONFIG_BUILD BUILD
#endif
////////////////////////////   Configuration files   /////////////////////////////////
//
// Environment configuration file (shared via MIT-shm)
#define MCS_FILE_NAME		"rfm-"CONFIG_BUILD
#define MCS_SHM_PLUGIN_FILE 	g_get_user_config_dir(),RC_DIR,MCS_FILE_NAME
// Gridview dbh preferences (Not environment)
#define GRID_GEOMETRY_FILE 	g_get_user_config_dir(),RC_DIR,"geometry.dbh"
#define GRID_PREFERENCES_FILE 	g_get_user_config_dir(),RC_DIR,"preferences.dbh"	
//deskview dbh preferences (Not environment)
#define DESK_PREFERENCES_FILE 	g_get_user_config_dir(),RC_DIR,"preferences-desk.dbh"
#define DESK_GEOMETRY_FILE 	g_get_user_config_dir(),RC_DIR,"deskview_geometry.dbh"
//
////////////////////////////   Cache files   /////////////////////////////////////////
// General cache directory
#define SETUP_FILE 		g_get_user_data_dir(),RC_DIR,"rodent-"BUILD
#define RFM_CACHE_DIR 		g_get_user_cache_dir(),RC_DIR,"cache"
// Specific cache directory for thumbnails
#define RFM_THUMBNAIL_DIR 	g_get_user_cache_dir(),RC_DIR,"thumbnails"
// DBH cache file for content emblems
#define MIME_COUNT_DBH_FILE 	g_get_user_cache_dir(),RC_DIR,"mimecount.dbh"
//
////////////////////////////   Data files   /////////////////////////////////////////
//
// Dialogs...
// Goto dialog history
#define GOTO_DBH_FILE 		g_get_user_data_dir(),RC_DIR,"golist.dbh"
// Run dialog flags
#define RUN_FLAG_FILE 		g_get_user_data_dir(),RC_DIR,"runflag.dbh"
// Run dialog history
#define RUN_DBH_FILE 		g_get_user_data_dir(),RC_DIR,"runlist.dbh"
// Workdir dialog history
#define WORKDIR_DBH_FILE 	g_get_user_data_dir(),RC_DIR,"workdir.dbh"
// Lp terminal history cache
#define LP_TERMINAL_HISTORY 	g_get_user_data_dir(),RC_DIR,"lp_terminal_history"
// Modules...
// Fgr module history autocompletion
#define FIND_DBH_FILE 		g_get_user_data_dir(),MODULE_DIR,"fgr_list.dbh"
#define FIND_PATHS_DBH_FILE 	g_get_user_data_dir(),MODULE_DIR,"fgr_paths_list.dbh"
#define FIND_GREP_DBH_FILE 	g_get_user_data_dir(),MODULE_DIR,"fgr_grep_list.dbh"
// Icon module xml files
#define ICON_MODULE_USER_XML	g_get_user_data_dir(),MODULE_DIR,"icons.mime.xml"
#define ICON_MODULE_XML		PACKAGE_DATA_DIR, MODULE_DIR, "icons.mime.xml"
#define USER_PIXMAPS		g_get_user_data_dir(), "pixmaps"
#define RODENT_THEME		PACKAGE_DATA_DIR,"icons","Rodent"
// Mime module files
#define APPLICATION_MIME_FILE 	PACKAGE_DATA_DIR,MODULE_DIR,"mime-module.xml"
#define USER_APPLICATIONS 	g_get_user_data_dir(),MODULE_DIR,"user-applications.2"
// Plugins...
// Fstab plugin mount point history
#define MOUNT_DBH_FILE 		g_get_user_data_dir(),PLUGIN_DIR,"mountdir.dbh"
// User defined mount types (local or monitor)
#define MOUNT_TYPE_DBH_FILE	g_get_user_data_dir(),PLUGIN_DIR,"mounttype.dbh"
// Fuse plugin keyfile
#define FUSE_KEY_FILE		g_get_user_data_dir(),PLUGIN_DIR,"fuse.ini"
// Bookmarks file (default gtk site)
#define BOOKMARKS_FILE		g_get_home_dir(),".gtk-bookmarks"
// Mimetype files 
#define FREEDESKTOP_MIME_FILE 	PACKAGE_DATA_DIR,RC_DIR,"freedesktop.org.xml"
#define MAGIC_MIME_FILE 	PACKAGE_DATA_DIR,RC_DIR,"types.xml"
//
////////////////////////////   General files   ///////////////////////////////////////
// Default desktop directory
#define DEFAULT_DESKTOP_DIR	g_get_home_dir(),_("Desktop")

==> rodent-4.9.2.tar.gz: rodent-4.9.2/files.h <==
/* files */
#define CONFIG_BUILD "6224"
#ifndef CONFIG_BUILD
# define CONFIG_BUILD BUILD
#endif
////////////////////////////   Configuration files   /////////////////////////////////
//
// Environment configuration file (shared via MIT-shm)
#define MCS_FILE_NAME		"rfm-"CONFIG_BUILD
#define MCS_SHM_PLUGIN_FILE 	g_get_user_config_dir(),RC_DIR,MCS_FILE_NAME
// Gridview dbh preferences (Not environment)
#define GRID_GEOMETRY_FILE 	g_get_user_config_dir(),RC_DIR,"geometry.dbh"
#define GRID_PREFERENCES_FILE 	g_get_user_config_dir(),RC_DIR,"preferences.dbh"

// Keybind customization file	
#define KEYBINDINGS_FILE 	g_get_user_config_dir(),RC_DIR,"keybind-6224.xml"
#define KEYBINDINGS_SCHEMA 	PACKAGE_DATA_DIR, MODULE_DIR,"keybind.xsd"

//deskview dbh preferences (Not environment)
#define DESK_PREFERENCES_FILE 	g_get_user_config_dir(),RC_DIR,"preferences-desk.dbh"
#define DESK_GEOMETRY_FILE 	g_get_user_config_dir(),RC_DIR,"deskview_geometry.dbh"
//
////////////////////////////   Cache files   /////////////////////////////////////////
// General cache directory
#define SETUP_FILE 		g_get_user_data_dir(),RC_DIR,"rodent-"BUILD
#define RFM_CACHE_DIR 		g_get_user_cache_dir(),RC_DIR,"cache"
// Specific cache directory for thumbnails
#define RFM_THUMBNAIL_DIR 	g_get_user_cache_dir(),RC_DIR,"thumbnails"
// DBH cache file for content emblems
#define MIME_COUNT_DBH_FILE 	g_get_user_cache_dir(),RC_DIR,"mimecount.dbh"
#define ICON_ID_DBH_FILE 	g_get_user_cache_dir(),RC_DIR,"icon_id.2.dbh"
//
////////////////////////////   Data files   /////////////////////////////////////////
//
// Dialogs...
// Goto dialog history
#define GOTO_DBH_FILE 		g_get_user_data_dir(),RC_DIR,"golist.dbh"
// Run dialog flags
#define RUN_FLAG_FILE 		g_get_user_data_dir(),RC_DIR,"runflag.dbh"
// Run dialog history
#define RUN_DBH_FILE 		g_get_user_data_dir(),RC_DIR,"runlist.dbh"
// Workdir dialog history
#define WORKDIR_DBH_FILE 	g_get_user_data_dir(),RC_DIR,"workdir.dbh"
// Lp terminal history cache
#define LP_TERMINAL_HISTORY 	g_get_user_data_dir(),RC_DIR,"lp_terminal_history"
// Modules...
// Fgr module history autocompletion
#define FIND_DBH_FILE 		g_get_user_data_dir(),MODULE_DIR,"fgr_list.dbh"
#define FIND_PATHS_DBH_FILE 	g_get_user_data_dir(),MODULE_DIR,"fgr_paths_list.dbh"
#define FIND_GREP_DBH_FILE 	g_get_user_data_dir(),MODULE_DIR,"fgr_grep_list.dbh"
// Icon module xml files
#define ICON_MODULE_USER_XML	g_get_user_data_dir(),MODULE_DIR,"icons.mime.xml"
#define ICON_MODULE_XML		PACKAGE_DATA_DIR, MODULE_DIR, "icons.mime.xml"
#define USER_PIXMAPS		g_get_user_data_dir(), "pixmaps"
#define RODENT_THEME		PACKAGE_DATA_DIR,"icons","Rodent"
// Mime module files
#define APPLICATION_MIME_FILE 	PACKAGE_DATA_DIR,MODULE_DIR,"mime-module.xml"
#define USER_APPLICATIONS 	g_get_user_data_dir(),MODULE_DIR,"user-applications.2"
// ...
// Callbacks mount point dialog files
#define MOUNT_DBH_FILE 		g_get_user_data_dir(),MODULE_DIR,"mountdir.dbh"
#define MOUNT_HISTORY_FILE 	g_get_user_data_dir(),MODULE_DIR,"mountdir.txt"
// Plugins...
// User defined mount types (local or monitor) in fstab plugin
#define MOUNT_TYPE_DBH_FILE	g_get_user_data_dir(),PLUGIN_DIR,"mounttype.dbh"
// Fuse plugin keyfile
#define FUSE_KEY_FILE		g_get_user_data_dir(),PLUGIN_DIR,"fuse.ini"
// Bookmarks file (default gtk site)
#define BOOKMARKS_FILE		g_get_home_dir(),".gtk-bookmarks"
// Mimetype files 
#define FREEDESKTOP_MIME_FILE 	PACKAGE_DATA_DIR,RC_DIR,"freedesktop.org.xml"
#define MAGIC_MIME_FILE 	PACKAGE_DATA_DIR,RC_DIR,"types.xml"
//
////////////////////////////   General files   ///////////////////////////////////////
// Default desktop directory
#define DEFAULT_DESKTOP_DIR	g_get_home_dir(),_("Desktop")
